<?php
/*
 *                      Fr_Util_Pagination.php
 *                    ------------------
 * Creat            : 12-jun-2006
 * Modificat        :
 * Versi           : 1.0
 * Autor            : J.Emilio Navarro
 *
 * Descripci       : 
 * 
 */

require_once('propel/util/Criteria.php');
 
abstract class FR_Pagination extends FR_Object_DB {
 	
 	/* Variables para la configuracin de la paginacin */
 	
 	protected  $limit; 	/* Nmero de elementos mximo por pgina. */	
	protected $num_pages; /* Nmero de pagines que se van a tener */
	protected $num_elem; 	/* Nmero de elementos que hay para mostrar  */
	protected $max_elem_page; /*Numero de elementos maximo por pagina.*/	
	
	/* Variables para identificar el objeto que esta representando la paginacion */
	
	protected $peerClass;  /* Classe Peer encargada de realizar el acceso a BD */
	protected $baseClass;  /* Nombre de la classe base que instancie el modulo de paginacin.*/ 
	protected $instance;   /* Instancia en base de la cual se realiza la paginacin */
	protected $objects;    /* Array de Objetos que seran mostrados en la pgina que se va a cargar */
	
	/* Informacion para Identificar el modulo que ha relizado la llamada a la paginacion */
	
	protected $moduleName;   	/* Nombre del modulo que ha realizado la peticin. */
	protected $className; /* Nombre de la classe ha llamar. */
	
	protected $result; /*Almacena las variables resultantes del calculo de la paginacion*/



public function __construct($class,$module,$actionClass,$cri_=null){
		
		$this->baseClass = $class;
		$this->peerClass = $class.'Peer'; 
		$this->instance = new $this->peerClass();		
		
		$this->moduleName = $module;
		$this->className = $actionClass;
		
		$this->result = array();		
		$this->init($cri_); /* Si se define un criterio de busqueda para el campo nombre. ex:a%*/
	
	}
	
public function init($cri){
	
		$this->limit = 10; /* HAURA DE SER LA DEFINIDA PER EL USUARI */	
		// "<br/> CLASSE".$this->clas;	
		
		$c = new Criteria();		
		$colum = $this->baseClass.'Name';	
	
						/* Si s'ha definido un criterio mas especifico. Para la columna Name */
		if(isset($cri)) { 
			$col= $this->baseClass.'.'.$colum; /* Acceso a la columna de la base de datos. Ex.Album.AlbumName */
			$c->add($col,$cri,Criteria::LIKE);
		}
							
		$this->objects = $this->instance->doSelect($c);			
		$this->num_elem = count($this->objects);		  /* Numero de elementos a representar */
		
		/*Si hay menos elementos que el limite, definimos como limite el numero de elementos. */
		if($this->num_elem < $this->limit)	$this->limit = $this->num_elem; 
		
		/* Si no hay paginas evitamos la division por 0 */
		
		if(0 == $this->limit)  $this->num_pages = 0;
		else $this->num_pages = $this->num_elem /$this->limit; /* Calculo cuantas pgines se necesitan para representar todos los elementos */
		
		//echo "<br/> Numero elementos OBJETOS:".count($this->objects	);
		//echo "<br/> Numero elementos INIT:".$this->num_pages;				
}

abstract protected function initCriteria($cri);
	
/*
 * Da la estructura base para hacer la paginacion. 
 * */
protected function getPagesStructure($cri = null) {
		
 try {	
		$pages = array();					
		
		if($this->num_pages!=0) /*si hay paginas*/
		{
				$c = $this->initCriteria($cri);		
				
										
				$this->objects = $this->instance->doSelect($c);		
				
				$this->max_elem_page = count($this->objects); /* Elementos maximos que se tiene que representar en una pagina*/				
				$offset = 0;
			
				$event = 'getPagination'; /*Classe a llamar */
				
				/*Generaci de les pagines que s'han de mostrar '*/	
				for($i=1;$i<$this->num_pages + 1;$i++){
					
					$pages[$i] = WEB_PATH.'/index.php?module='.$this->moduleName.'&class='.$this->className.'&event='.$event.'&offset='.$offset;
					if(isset($cri))$pages[$i].='&criteria='.$cri;	 
					$offset += $this->limit;				
				}
				
			/*Contrucion del prev i next */										    /* P R E -- V I E W*/
			
			if ($_GET['offset'] > 0) 	$prev = $_GET['offset'] - $this->limit;   	
			else $prev = 0; 	 
			  		
			
			$prev = WEB_PATH.'/index.php?module='.$this->moduleName.'&class='.$this->className.'&event='.$event.'&offset='.$prev;
			
			if(isset($cri)) $prev.='&criteria='.$cri;
			
																					/* N E X T --  VIEW*/ 
																					
		    if ($_GET['offset'] < $offset-$this->limit) { //$offset tiene almacenado el desplazamiento mximo, calculado anteriormente.
		    	$next = $_GET['offset'] + $this->limit;   							   	
		    }
		    else $next = $_GET['offset'];  
		    
		    $next = WEB_PATH.'/index.php?module='.$this->moduleName.'&class='.$this->className.'&event='.$event.'&offset='.$next;
		    
		    if(isset($cri)) $next.='&criteria='.$cri;    
		    
		   /* FIN  PREV I  NEXT */
			 
			// Resultado de la operacion     		
			
			$this->result['objects'] = $this->objects; /*Objetos que se van a visualizar por pantalla.*/
			$this->result['offsets'] = $pages;
			$this->result['prev'] = $prev;	
			$this->result['next'] = $next;	
			
			return true;
			
		}
		else return false; /* No hay paginas para mostrar.*/
			
}
catch(PropelException $ex) {
	
	echo "<br/> Class: album.php -- FUNCTION:getAlbum ".$ex->getCause();	
	return false;	
}

}

/* Devuleve la lista de elementos a representar */

public function getObjects(){
	
	if (null != $this->result['objects']) return $this->result['objects'];
	else return false;
}

/*
 * Devuelve el nmero de paginas que se han trozeado segun el limit del usuario
 * 
 * */
public function getOffsets() {
	
	if (null != $this->result['offsets']) return $this->result['offsets'];
	else return false;
}

/*
 * Direccin de la pagina anterior a la actual
 * */
public function getPrev() {
	
	if (null != $this->result['prev']) return $this->result['prev'];
	else return false;
}

 /* 
  * Direccin de la pagina seiguiente a la actual
  * 
  */
 
public function getNext() {
	
	if (null != $this->result['next']) return $this->result['next'];
	else return false;
}

      public function __destruct()
      {
         unset($this->limit);
         unset($this->num_pages);
         unset($this->num_elem);
         unset($this->peerClass);
         unset($this->baseClass);
         unset($this->instance);
         unset($this->objects);
         unset($this->moduleName);
         unset($this->className);
         unset($this->result);
         
      }





 	
}
 
?>
