
DROP DATABASE IF EXISTS `feelmusic22`;


CREATE DATABASE `feelmusic22`;

USE `feelmusic22`;

DROP TABLE IF EXISTS links;

CREATE TABLE Links (
  IdLinks INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  Url VARCHAR(255) NULL,
  LinkComment TEXT NULL,
  PRIMARY KEY(IdLinks)
)TYPE = MYISAM;

DROP TABLE IF EXISTS languages;

CREATE TABLE Languages (
  IdLanguages TINYINT(5) UNSIGNED NOT NULL AUTO_INCREMENT,
  Language VARCHAR(100) NOT NULL,
  PRIMARY KEY(IdLanguages)
)TYPE = MYISAM;

INSERT INTO Languages (Language) VALUES('Catalan');
INSERT INTO Languages (Language) VALUES('Spanish'); 
INSERT INTO Languages (Language) VALUES('English'); 

DROP TABLE IF EXISTS user_types;

CREATE TABLE User_Types (
  IdUserType TINYINT UNSIGNED NOT NULL AUTO_INCREMENT,
  Description VARCHAR(10) NULL,
  PRIMARY KEY(IdUserType)
)TYPE = MYISAM;

INSERT INTO User_Types (Description) VALUES('Demo');
INSERT INTO User_Types (Description) VALUES('User');
INSERT INTO User_Types (Description) VALUES('Admin'); 

DROP TABLE IF EXISTS multimedia_elem;

CREATE TABLE Multimedia_Elem (
  IdMultimediaElem INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdMultimediaType SMALLINT(4) UNSIGNED NOT NULL,
  ElemDescription VARCHAR(150) NULL,
  Size TINYINT UNSIGNED NULL,
  PRIMARY KEY(IdMultimediaElem),
  INDEX Multimedia_Elem_FKIndex1(IdMultimediaType)
)TYPE = MYISAM;

DROP TABLE IF EXISTS application_config;

CREATE TABLE application_config (
  Directories VARCHAR(255) NULL,
  NotUsedSongs MEDIUMINT(4) UNSIGNED NOT NULL DEFAULT 365,
  MaxMultElemSize TINYINT(4) UNSIGNED NOT NULL DEFAULT 4,
  MaxByteWeb INTEGER(5) UNSIGNED NOT NULL DEFAULT 100,
  UsersValidation BOOL NOT NULL DEFAULT 1,
  SessionTime INTEGER(10) UNSIGNED NULL
)TYPE = MYISAM;

INSERT INTO application_config (NotUsedSongs, MaxMultElemSize, MaxByteWeb, UsersValidation) VALUES(365,4,100,1);

DROP TABLE IF EXISTS users;

CREATE TABLE Users (
  UserID INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdUserType TINYINT UNSIGNED NOT NULL,
  UserLogin VARCHAR(20) NULL,
  Pass VARCHAR(100) NULL,
  Name VARCHAR(100) NULL,
  FirstName VARCHAR(100) NULL,
  LastName VARCHAR(100) NULL,
  Email VARCHAR(100) NULL,
  BirthDate DATE NULL,
  CreateDate DATE NULL,
  Active BOOL NOT NULL DEFAULT 1,
  MaxMegas INTEGER UNSIGNED NOT NULL DEFAULT 250,
  UsedMegas INTEGER UNSIGNED NOT NULL DEFAULT 0,
  EmotionsMaxPoint TINYINT UNSIGNED NOT NULL DEFAULT 5,
  EmotionsTypeSelection TINYINT UNSIGNED NOT NULL DEFAULT 1,
  PreferentTop10 VARCHAR(100) NOT NULL DEFAULT '2,4,6,8,10',
  ViewLinks BOOL NULL DEFAULT 1,
  PrefLanguages TINYINT UNSIGNED NULL,
  OffsetPagination TINYINT UNSIGNED NULL,
  PRIMARY KEY(UserID),
  INDEX Users_FKIndex1(IdUserType)
)TYPE = MYISAM;

INSERT INTO Users (idUserType, UserLogin, Pass, Name) VALUES(3,'Admin' ,'','Admin' );

DROP TABLE IF EXISTS Session;

CREATE TABLE Session (
  IdSession VARCHAR(32) NOT NULL,
  UserID INTEGER(11) UNSIGNED NOT NULL,
  Expire INTEGER(11) UNSIGNED NULL,
  value TEXT NULL,
  PRIMARY KEY(IdSession)
)TYPE = MYISAM;



DROP TABLE IF EXISTS playList;

CREATE TABLE PlayList (
  IdPlayList INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdMusicElementType TINYINT UNSIGNED NOT NULL DEFAULT 5,
  UserID INTEGER(11) UNSIGNED NOT NULL,
  PlayListName VARCHAR(150) NOT NULL,
  CreationDate DATE NULL,
  PublicList BOOL NOT NULL DEFAULT 0,
  PlayListTime INTEGER UNSIGNED NULL,
  TotalSongs SMALLINT UNSIGNED NULL,
  PRIMARY KEY(IdPlayList),
  INDEX PlayList_FKIndex1(UserID)
)TYPE = MYISAM;

DROP TABLE IF EXISTS observations;

CREATE TABLE Observations (
  IdObservation INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  UserID INTEGER(11) UNSIGNED NOT NULL,
  ObservationTitle VARCHAR(255) NOT NULL,
  Place VARCHAR(255) NULL,
  People VARCHAR(255) NULL,
  Coment VARCHAR(255) NULL,
  Url VARCHAR(255) NULL,
  Image VARCHAR(255) NULL,
  ObserDate DATE NULL,  
  PRIMARY KEY(IdObservation),
  INDEX Observations_FKIndex1(UserID)
)TYPE = MYISAM;

DROP TABLE IF EXISTS emotions;

CREATE TABLE Emotions (
  IdEmotion INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  UserID INTEGER(11) UNSIGNED NOT NULL,
  EmotionName VARCHAR(100) NOT NULL,
  UrlIcon VARCHAR(255) NOT NULL,
  PRIMARY KEY(IdEmotion),
  INDEX Emotions_FKIndex1(UserID)
)TYPE = MYISAM;


INSERT INTO Emotions (UserID, EmotionName, UrlIcon) VALUES(1,'1',' ');
INSERT INTO Emotions (UserID, EmotionName, UrlIcon) VALUES(1,'2',' ');
INSERT INTO Emotions (UserID, EmotionName, UrlIcon) VALUES(1,'3',' ');
INSERT INTO Emotions (UserID, EmotionName, UrlIcon) VALUES(1,'4',' '); 

DROP TABLE IF EXISTS Emotions_has_Observations;

CREATE TABLE Emotions_has_Observations (
  IdEmotion INTEGER(11) UNSIGNED NOT NULL,
  IdObservation INTEGER(11) UNSIGNED NOT NULL,
  PRIMARY KEY(IdEmotion, IdObservation),
  INDEX Emotions_has_Observations_FKIndex1(IdEmotion),
  INDEX Emotions_has_Observations_FKIndex2(IdObservation)
)TYPE = MYISAM;

DROP TABLE IF EXISTS Emotion_Search;

CREATE TABLE Emotion_Search (
  IdEmotion_Search INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdEmotion INTEGER(11) UNSIGNED NOT NULL,
  UserID INTEGER(11) UNSIGNED NOT NULL,
  TypeFind TINYINT(3) UNSIGNED NULL,
  FindIn VARCHAR(15) NOT NULL DEFAULT 1,
  PointIni TINYINT(3) UNSIGNED NULL,
  PointFi TINYINT(3) UNSIGNED NULL,
  maxSongs INTEGER(7) UNSIGNED NOT NULL DEFAULT 10,
  InitDate DATE NULL,
  FinDate DATE NULL,
  PRIMARY KEY(IdEmotion_Search),
  INDEX Emotion_Search_FKIndex1(UserID),
  INDEX Emotion_Search_FKIndex2(IdEmotion)
)TYPE = MYISAM;

DROP TABLE IF EXISTS language_Literal;

CREATE TABLE Language_Literal (
  IdLanguageLiteral INTEGER UNSIGNED NOT NULL,
  IdLanguages TINYINT(5) UNSIGNED NOT NULL,
  Literal VARCHAR(255) NULL,
  PRIMARY KEY(IdLanguageLiteral,IdLanguages),
  INDEX LanguageText_FKIndex1(IdLanguages)
)TYPE = MYISAM;

DROP TABLE IF EXISTS album;

CREATE TABLE Album (
  IdAlbum INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdMusicElementType TINYINT UNSIGNED NOT NULL DEFAULT 3,
  IdCovers INTEGER(11) UNSIGNED NULL,
  AlbumName VARCHAR(255) NULL,
  AlbumYear MEDIUMINT(4) UNSIGNED NULL,
  PRIMARY KEY(IdAlbum),
  INDEX Album_FKIndex1(IdCovers)
)TYPE = MYISAM;


--  O R P H A N E D   A L B U M 

INSERT INTO Album (IdMusicElementType,AlbumName,AlbumYear) VALUES (3,'Orphaned', '1900');




DROP TABLE IF EXISTS music_element_type;

CREATE TABLE Music_Element_Type (
  IdMusicElementType TINYINT UNSIGNED NOT NULL AUTO_INCREMENT,
  ElementDesc VARCHAR(150) BINARY NOT NULL,
  PRIMARY KEY(IdMusicElementType)
)TYPE = MYISAM;

INSERT INTO Music_Element_Type(ElementDesc) VALUES('Song'); -- 1
INSERT INTO Music_Element_Type(ElementDesc) VALUES('Artist'); -- 2 
INSERT INTO Music_Element_Type(ElementDesc) VALUES('Album');  -- 3
INSERT INTO Music_Element_Type(ElementDesc) VALUES('Genere');  -- 4
INSERT INTO Music_Element_Type(ElementDesc) VALUES('PlayList'); -- 5

DROP TABLE IF EXISTS artist;

CREATE TABLE artist (
  IdArtist INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdMusicElementType TINYINT  NOT NULL DEFAULT 2,
  ArtistName VARCHAR(255) NULL,
  PRIMARY KEY(IdArtist)
)TYPE = MYISAM;

--  A N O N I M  E    A R T I S T A 

INSERT INTO Artist (IdMusicElementType,ArtistName) VALUES (2,'Anonime');

DROP TABLE IF EXISTS genere;

CREATE TABLE genere (
  IdGenere INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdMusicElementType TINYINT UNSIGNED  NOT NULL DEFAULT 4,
  GenereName VARCHAR(255) NULL,
  PRIMARY KEY(IdGenere),
  INDEX Genere_FKIndex1(IdMusicElementType)
)TYPE = MYISAM;

-- U N K N O W N   G E N E R E 

INSERT INTO Genere (IdMusicElementType,GenereName) VALUES (4,'Unknown');

DROP TABLE IF EXISTS agenda;

CREATE TABLE Agenda (
  IdAgenda INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdMusicElementType TINYINT UNSIGNED NULL,
  IdMusicElement INTEGER UNSIGNED NULL,
  IdObservation INTEGER(11) UNSIGNED NOT NULL,
  UserID INTEGER(11) UNSIGNED NOT NULL,
  Title VARCHAR(255) NOT NULL,
  NoticeDate DATE NULL,
  NoticeTime TIME NULL,
  Active BOOL NULL, 
  PRIMARY KEY(IdAgenda),
  INDEX Agenda_FKIndex1(UserID),
  INDEX Agenda_FKIndex2(IdObservation),
  INDEX Agenda_FKIndex3(IdMusicElementType),
  INDEX Agenda_FKIndex4(IdMusicElement),
  INDEX Agenda_FKIndex5(UserID)
)TYPE = MYISAM;

DROP TABLE IF EXISTS user_links;


CREATE TABLE User_Links (
  IdUserLinks INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdArtist INTEGER(11) UNSIGNED NOT NULL,
  IdLinks INTEGER(11) UNSIGNED NOT NULL,
  UserID INTEGER(11) UNSIGNED NOT NULL,
  LastAccesDate DATE NULL,
  LastAccesTime TIME NULL,
  NumAcces SMALLINT UNSIGNED NULL,
  PRIMARY KEY(IdUserLinks),
  INDEX UserLinks_FKIndex1(IdLinks),
  INDEX UserLinks_FKIndex2(UserID),
  INDEX User_Links_FKIndex3(IdArtist)
)TYPE = MYISAM;

DROP TABLE IF EXISTS Song;

CREATE TABLE song (
  IdSong INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdAlbum INTEGER(11) UNSIGNED NOT NULL,
  IdMusicElementType TINYINT UNSIGNED NOT NULL DEFAULT 1,
  IdGenere INTEGER(11) UNSIGNED NOT NULL,
  IdArtist INTEGER(11) UNSIGNED NOT NULL,
  UrlFile VARCHAR(255) NOT NULL,
  EnterDate DATE NULL,
  SongName VARCHAR(255) NULL,
  Track SMALLINT(2) UNSIGNED NULL,
  Time MEDIUMINT(5) UNSIGNED NULL,
  FileSize INT(11) NULL,
  Bitrate MEDIUMINT(5) UNSIGNED NULL,
  FileName VARCHAR(255) NULL,
  Format VARCHAR(3) NULL,
  Rate MEDIUMINT(2) UNSIGNED NULL,
  Mode VARCHAR(25) NULL,
  Mime VARCHAR(255) NULL,
  Image BOOL NOT NULL DEFAULT 0,
  Complete BOOL NOT NULL DEFAULT 0,
  PRIMARY KEY(IdSong),
  INDEX Song_FKIndex1(IdArtist),
  INDEX Song_FKIndex2(IdAlbum),
  INDEX Song_FKIndex3(IdGenere)  
)TYPE = MYISAM;

DROP TABLE IF EXISTS now_Playing;

CREATE TABLE Now_Playing (
  idNowPlaying SMALLINT(5) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdSong INTEGER(11) UNSIGNED NOT NULL,
  UserID INTEGER(11) UNSIGNED NOT NULL,
  Session VARCHAR(64) NOT NULL,
  PRIMARY KEY(idNowPlaying),
  INDEX NowPlaying_FKIndex1(UserID),
  INDEX Now_Playing_FKIndex2(IdSong)
)TYPE = MYISAM;


DROP TABLE IF EXISTS user_use_play;

CREATE TABLE User_Use_Play (
  IdUserUsePlay INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdMusicElementType TINYINT UNSIGNED NOT NULL,
  IdObservation INTEGER(11) UNSIGNED NULL,
  UserID INTEGER(11) UNSIGNED NOT NULL,
  IdEmotion INTEGER(11) UNSIGNED NULL,
  CountPlay INTEGER UNSIGNED NOT NULL DEFAULT 0,
  FirstPlayDate DATE NULL,
  LastPlayDate DATE NULL,
  ElemPunctuation INTEGER(11) NOT NULL DEFAULT 0,
  IdMusicElement INTEGER(11) UNSIGNED NOT NULL,
  PRIMARY KEY(IdUserUsePlay),
  INDEX User_Use_Play_FKIndex1(IdEmotion),
  INDEX User_Use_Play_FKIndex2(UserID),
  INDEX User_Use_Play_FKIndex3(IdObservation)  
)TYPE = MYISAM;

DROP TABLE IF EXISTS reprod_hist;

CREATE TABLE Reprod_Hist (
  IdPlayHist INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdUserUsePlay INTEGER(11) UNSIGNED NOT NULL,
  PlayDate DATE NOT NULL,
  PlayTime TIME NOT NULL,
  PRIMARY KEY(IdPlayHist),
  INDEX Reprod_Hist_FKIndex1(IdUserUsePlay)
)TYPE = MYISAM;

DROP TABLE IF EXISTS playlist_has_song;

CREATE TABLE PlayList_has_Song (
  IdPlayList INTEGER(11) UNSIGNED NOT NULL,
  IdSong INTEGER(11) UNSIGNED NOT NULL,
  Track SMALLINT(3) UNSIGNED NULL,
  PRIMARY KEY(IdPlayList, IdSong),
  INDEX PlayList_has_Song_FKIndex1(IdPlayList),
  INDEX PlayList_has_Song_FKIndex2(IdSong)
)TYPE = MYISAM;

DROP TABLE IF EXISTS Favorite_Songs;

CREATE TABLE Favorite_Songs (
  IdFavoriteSongs INTEGER(11) UNSIGNED NOT NULL AUTO_INCREMENT,
  IdSong INTEGER(11) UNSIGNED NOT NULL,
  UserID INTEGER(11) UNSIGNED NOT NULL,
  Date DATE NULL,
  PRIMARY KEY(IdFavoriteSongs),
  INDEX FavoriteSongs_FKIndex1(UserID),
  INDEX FavoriteSongs_FKIndex2(IdSong)
)TYPE = MYISAM;

-- INSERT DE LITERALES

INSERT INTO `language_literal` VALUES (11, 1, 'Random');
INSERT INTO `language_literal` VALUES (11, 2, 'Random');
INSERT INTO `language_literal` VALUES (11, 3, 'Random');
INSERT INTO `language_literal` VALUES (12, 1, 'Ant');
INSERT INTO `language_literal` VALUES (12, 2, 'Ant');
INSERT INTO `language_literal` VALUES (12, 3, 'Prev');
INSERT INTO `language_literal` VALUES (13, 1, 'Seg');
INSERT INTO `language_literal` VALUES (13, 2, 'Seg');
INSERT INTO `language_literal` VALUES (13, 3, 'Next');
INSERT INTO `language_literal` VALUES (14, 1, 'Tot');
INSERT INTO `language_literal` VALUES (14, 2, 'Todo');
INSERT INTO `language_literal` VALUES (14, 3, 'All');
INSERT INTO `language_literal` VALUES (15, 1, 'EXAMINAR');
INSERT INTO `language_literal` VALUES (15, 2, 'EXAMINAR');
INSERT INTO `language_literal` VALUES (15, 3, 'BROWSE');
INSERT INTO `language_literal` VALUES (16, 1, 'analitzar');
INSERT INTO `language_literal` VALUES (16, 2, 'analizar');
INSERT INTO `language_literal` VALUES (16, 3, 'analyze');
INSERT INTO `language_literal` VALUES (17, 1, 'PAS 1: Analitzant directoris.');
INSERT INTO `language_literal` VALUES (10, 3, 'Play');
INSERT INTO `language_literal` VALUES (10, 2, 'Play');
INSERT INTO `language_literal` VALUES (10, 1, 'Play');
INSERT INTO `language_literal` VALUES (9, 3, 'Action');
INSERT INTO `language_literal` VALUES (9, 2, 'Accin');
INSERT INTO `language_literal` VALUES (9, 1, 'Acci');
INSERT INTO `language_literal` VALUES (8, 3, 'Year');
INSERT INTO `language_literal` VALUES (8, 2, 'Ao');
INSERT INTO `language_literal` VALUES (8, 1, 'Any');
INSERT INTO `language_literal` VALUES (7, 3, 'Song');
INSERT INTO `language_literal` VALUES (7, 2, 'Cancin');
INSERT INTO `language_literal` VALUES (7, 1, 'Cano');
INSERT INTO `language_literal` VALUES (6, 3, 'Artist');
INSERT INTO `language_literal` VALUES (6, 2, 'Artista');
INSERT INTO `language_literal` VALUES (3, 1, 'Rabia');
INSERT INTO `language_literal` VALUES (3, 2, 'Rabia');
INSERT INTO `language_literal` VALUES (3, 3, 'Anger');
INSERT INTO `language_literal` VALUES (4, 1, 'Por');
INSERT INTO `language_literal` VALUES (4, 2, 'Miedo');
INSERT INTO `language_literal` VALUES (4, 3, 'Fright');
INSERT INTO `language_literal` VALUES (5, 1, 'lbum');
INSERT INTO `language_literal` VALUES (5, 2, 'lbum');
INSERT INTO `language_literal` VALUES (5, 3, 'Album');
INSERT INTO `language_literal` VALUES (6, 1, 'Artista');
INSERT INTO `language_literal` VALUES (2, 3, 'Sadness');
INSERT INTO `language_literal` VALUES (2, 2, 'Tristeza');
INSERT INTO `language_literal` VALUES (2, 1, 'Tristesa');
INSERT INTO `language_literal` VALUES (1, 3, 'Joy');
INSERT INTO `language_literal` VALUES (1, 2, 'Alegria');
INSERT INTO `language_literal` VALUES (1, 1, 'Alegria');
INSERT INTO `language_literal` VALUES (31, 2, 'Tamao');
INSERT INTO `language_literal` VALUES (31, 1, 'Tamany');
INSERT INTO `language_literal` VALUES (30, 3, 'Repeated songs ');
INSERT INTO `language_literal` VALUES (30, 2, 'Canciones repetidas');
INSERT INTO `language_literal` VALUES (30, 1, 'Canons repetides');
INSERT INTO `language_literal` VALUES (29, 3, 'New songs');
INSERT INTO `language_literal` VALUES (29, 2, 'Nuevas canciones');
INSERT INTO `language_literal` VALUES (28, 3, 'New artists');
INSERT INTO `language_literal` VALUES (29, 1, 'Noves canons');
INSERT INTO `language_literal` VALUES (28, 2, 'Nuevos artistas');
INSERT INTO `language_literal` VALUES (28, 1, 'Nous rtistes');
INSERT INTO `language_literal` VALUES (27, 2, 'Nuevos  lbumes');
INSERT INTO `language_literal` VALUES (27, 3, 'New albums');
INSERT INTO `language_literal` VALUES (26, 3, 'STEP 2: Saving songs');
INSERT INTO `language_literal` VALUES (26, 2, 'PASO 2: Guardando canciones');
INSERT INTO `language_literal` VALUES (26, 1, 'PAS 2: Guardant canons');
INSERT INTO `language_literal` VALUES (25, 3, 'Directories analyzed in ');
INSERT INTO `language_literal` VALUES (25, 2, 'Directorio analizado en');
INSERT INTO `language_literal` VALUES (25, 1, 'Directori analitzat en ');
INSERT INTO `language_literal` VALUES (24, 3, 'Error file');
INSERT INTO `language_literal` VALUES (24, 2, 'Archivos con error');
INSERT INTO `language_literal` VALUES (24, 1, 'Arxius amb error');
INSERT INTO `language_literal` VALUES (23, 3, 'Incompatibles');
INSERT INTO `language_literal` VALUES (23, 2, 'Incompatibles');
INSERT INTO `language_literal` VALUES (23, 1, 'Incompatibles');
INSERT INTO `language_literal` VALUES (22, 3, 'Incomplets');
INSERT INTO `language_literal` VALUES (22, 2, 'Incompletos');
INSERT INTO `language_literal` VALUES (21, 2, 'Completos');
INSERT INTO `language_literal` VALUES (21, 3, 'Completes');
INSERT INTO `language_literal` VALUES (22, 1, 'Incomplets');
INSERT INTO `language_literal` VALUES (20, 3, 'Compatibles');
INSERT INTO `language_literal` VALUES (20, 2, 'Compatibles');
INSERT INTO `language_literal` VALUES (20, 1, 'Compatibles');
INSERT INTO `language_literal` VALUES (19, 3, 'Analyzed ');
INSERT INTO `language_literal` VALUES (19, 2, 'Analizados');
INSERT INTO `language_literal` VALUES (19, 1, 'Analitzats');
INSERT INTO `language_literal` VALUES (18, 3, 'Files');
INSERT INTO `language_literal` VALUES (18, 2, 'Archivos');
INSERT INTO `language_literal` VALUES (18, 1, 'Arxius');
INSERT INTO `language_literal` VALUES (17, 3, 'STEP 1: Analyzing directories.');
INSERT INTO `language_literal` VALUES (21, 1, 'Completes');
INSERT INTO `language_literal` VALUES (17, 2, 'PASO 1: Analizando directorios.');
INSERT INTO `language_literal` VALUES (27, 1, 'Nous lbums');
INSERT INTO `language_literal` VALUES (31, 3, 'Size');
INSERT INTO `language_literal` VALUES (32, 1, 'Temps de msica');
INSERT INTO `language_literal` VALUES (32, 2, 'Tiempo de msica');
INSERT INTO `language_literal` VALUES (32, 3, 'Music time');
INSERT INTO `language_literal` VALUES (33, 1, 'Arxius guardats en');
INSERT INTO `language_literal` VALUES (33, 2, 'Archivos guardados');
INSERT INTO `language_literal` VALUES (33, 3, 'Files saved in');
INSERT INTO `language_literal` VALUES (34, 1, 'segons');
INSERT INTO `language_literal` VALUES (34, 2, 'segundos');
INSERT INTO `language_literal` VALUES (34, 3, 'seconds');
INSERT INTO `language_literal` VALUES (35, 1, 'Identificaci');
INSERT INTO `language_literal` VALUES (35, 2, 'Identificacin');
INSERT INTO `language_literal` VALUES (35, 3, 'Login');
INSERT INTO `language_literal` VALUES (36, 1, 'Paraula de pas');
INSERT INTO `language_literal` VALUES (36, 2, 'Contrasea');
INSERT INTO `language_literal` VALUES (36, 3, 'Password');
INSERT INTO `language_literal` VALUES (37, 1, 'Nom');
INSERT INTO `language_literal` VALUES (37, 2, 'Nombre');
INSERT INTO `language_literal` VALUES (37, 3, 'Name');
INSERT INTO `language_literal` VALUES (38, 1, 'Email');
INSERT INTO `language_literal` VALUES (38, 2, 'Email');
INSERT INTO `language_literal` VALUES (38, 3, 'Email');
INSERT INTO `language_literal` VALUES (39, 1, 'Data Naixement ');
INSERT INTO `language_literal` VALUES (39, 2, 'Fecha Nacimiento');
INSERT INTO `language_literal` VALUES (39, 3, 'Birth Date');
INSERT INTO `language_literal` VALUES (40, 1, '1er Cognom');
INSERT INTO `language_literal` VALUES (40, 2, '1er Apellido');
INSERT INTO `language_literal` VALUES (40, 3, 'First Name');
INSERT INTO `language_literal` VALUES (41, 1, '2on Cognom');
INSERT INTO `language_literal` VALUES (41, 2, '2on Apellido');
INSERT INTO `language_literal` VALUES (41, 3, 'Last Name');
INSERT INTO `language_literal` VALUES (42, 1, 'Donar-s''hi d''alta');
INSERT INTO `language_literal` VALUES (42, 2, 'Darse de alta');
INSERT INTO `language_literal` VALUES (42, 3, 'Register');
INSERT INTO `language_literal` VALUES (43, 1, 'Lloc');
INSERT INTO `language_literal` VALUES (43, 2, 'Lugar');
INSERT INTO `language_literal` VALUES (43, 3, 'Place');
INSERT INTO `language_literal` VALUES (44, 1, 'Amics');
INSERT INTO `language_literal` VALUES (44, 2, 'Amigos');
INSERT INTO `language_literal` VALUES (44, 3, 'Friends');
INSERT INTO `language_literal` VALUES (45, 1, 'Url');
INSERT INTO `language_literal` VALUES (45, 2, 'Url');
INSERT INTO `language_literal` VALUES (45, 3, 'Url');
INSERT INTO `language_literal` VALUES (46, 1, 'Data');
INSERT INTO `language_literal` VALUES (46, 2, 'Fecha');
INSERT INTO `language_literal` VALUES (46, 3, 'Date');
INSERT INTO `language_literal` VALUES (47, 1, 'Hora');
INSERT INTO `language_literal` VALUES (47, 2, 'Hora');
INSERT INTO `language_literal` VALUES (47, 3, 'Time');
INSERT INTO `language_literal` VALUES (48, 1, 'Comentari');
INSERT INTO `language_literal` VALUES (48, 2, 'Comentario');
INSERT INTO `language_literal` VALUES (48, 3, 'Comment');
INSERT INTO `language_literal` VALUES (49, 1, 'Multimedia');
INSERT INTO `language_literal` VALUES (49, 2, 'Multimedia');
INSERT INTO `language_literal` VALUES (49, 3, 'Multimedia');
INSERT INTO `language_literal` VALUES (50, 1, 'Nou Multimedia');
INSERT INTO `language_literal` VALUES (50, 2, 'Nuevo Multimedia');
INSERT INTO `language_literal` VALUES (50, 3, 'New Multimedia');
INSERT INTO `language_literal` VALUES (51, 1, 'Alta');
INSERT INTO `language_literal` VALUES (51, 2, 'Nuevo');
INSERT INTO `language_literal` VALUES (51, 3, 'New');
INSERT INTO `language_literal` VALUES (52, 1, 'Element');
INSERT INTO `language_literal` VALUES (52, 2, 'Elemento');
INSERT INTO `language_literal` VALUES (52, 3, 'Element');
INSERT INTO `language_literal` VALUES (53, 1, 'Descripci');
INSERT INTO `language_literal` VALUES (53, 2, 'Descripcin');
INSERT INTO `language_literal` VALUES (53, 3, 'Description');
INSERT INTO `language_literal` VALUES (54, 1, 'Tornar');
INSERT INTO `language_literal` VALUES (54, 2, 'Volver');
INSERT INTO `language_literal` VALUES (54, 3, 'Back');
INSERT INTO `language_literal` VALUES (55, 1, 'No han arribat correctament les dades de les observacions. ');
INSERT INTO `language_literal` VALUES (55, 2, 'No han llegado correctamente los datos del las observaciones.');
INSERT INTO `language_literal` VALUES (55, 3, 'The observation data hasnt arrived correctly. ');
INSERT INTO `language_literal` VALUES (56, 1, 'Observacions donades dalta.');
INSERT INTO `language_literal` VALUES (56, 2, 'Observaciones dadas de alta. ');
INSERT INTO `language_literal` VALUES (56, 3, 'The observation has been created. ');
INSERT INTO `language_literal` VALUES (57, 1, 'Genere');
INSERT INTO `language_literal` VALUES (57, 2, 'Genero');
INSERT INTO `language_literal` VALUES (57, 3, 'Genere');
INSERT INTO `language_literal` VALUES (58, 1, 'Observaci modifcada.');
INSERT INTO `language_literal` VALUES (58, 2, 'Observaciones modificadas. ');
INSERT INTO `language_literal` VALUES (58, 3, 'The observation has been changed.');
INSERT INTO `language_literal` VALUES (59, 1, ' Modificar');
INSERT INTO `language_literal` VALUES (59, 2, ' Modificar');
INSERT INTO `language_literal` VALUES (59, 3, 'Alter');
INSERT INTO `language_literal` VALUES (60, 1, 'Veure');
INSERT INTO `language_literal` VALUES (60, 2, 'Ver');
INSERT INTO `language_literal` VALUES (60, 3, 'View ');
INSERT INTO `language_literal` VALUES (61, 1, 'Reproduccions');
INSERT INTO `language_literal` VALUES (61, 2, 'Reproducciones');
INSERT INTO `language_literal` VALUES (61, 3, 'Plays');
INSERT INTO `language_literal` VALUES (62, 1, 'Total ');
INSERT INTO `language_literal` VALUES (62, 2, 'Total ');
INSERT INTO `language_literal` VALUES (62, 3, 'Total ');
INSERT INTO `language_literal` VALUES (63, 1, 'Usuaris ');
INSERT INTO `language_literal` VALUES (63, 2, 'Usuarios');
INSERT INTO `language_literal` VALUES (63, 3, 'Users');
INSERT INTO `language_literal` VALUES (64, 1, 'Puntuaci');
INSERT INTO `language_literal` VALUES (64, 2, 'Puntuacin');
INSERT INTO `language_literal` VALUES (64, 3, 'Punctuation');
INSERT INTO `language_literal` VALUES (65, 1, 'Associar');
INSERT INTO `language_literal` VALUES (65, 2, 'Asociar');
INSERT INTO `language_literal` VALUES (65, 3, 'Set');
INSERT INTO `language_literal` VALUES (66, 1, 'No hi ha observacions.');
INSERT INTO `language_literal` VALUES (66, 2, 'No hay observaciones.');
INSERT INTO `language_literal` VALUES (66, 3, 'There arent defined observations.');
INSERT INTO `language_literal` VALUES (67, 1, 'Eliminar');
INSERT INTO `language_literal` VALUES (67, 2, 'Eliminar');
INSERT INTO `language_literal` VALUES (67, 3, 'Delete');
INSERT INTO `language_literal` VALUES (68, 1, 'La observaci s''ha esborrat correctament.');
INSERT INTO `language_literal` VALUES (68, 2, 'La observacin se ha borrado correctamente.');
INSERT INTO `language_literal` VALUES (68, 3, 'The observation has been deleted successfully. ');
INSERT INTO `language_literal` VALUES (69, 1, 'Tanca');
INSERT INTO `language_literal` VALUES (69, 2, 'Cerrar');
INSERT INTO `language_literal` VALUES (69, 3, 'Close');
INSERT INTO `language_literal` VALUES (70, 1, 'No hi ha lbums a mostrar.');
INSERT INTO `language_literal` VALUES (70, 2, 'No hay lbumes a mostrar. ');
INSERT INTO `language_literal` VALUES (70, 3, 'There aren''t albums to show.');
INSERT INTO `language_literal` VALUES (71, 1, 'No hi ha Artistes a mostrar.');
INSERT INTO `language_literal` VALUES (71, 2, 'No hay Artistas a mostrar.');
INSERT INTO `language_literal` VALUES (71, 3, 'There aren''t Artist to show.');
INSERT INTO `language_literal` VALUES (72, 1, 'Emocions');
INSERT INTO `language_literal` VALUES (72, 2, 'Emociones');
INSERT INTO `language_literal` VALUES (72, 3, 'Emotions ');
INSERT INTO `language_literal` VALUES (73, 1, 'Observacions');
INSERT INTO `language_literal` VALUES (73, 2, 'Observaciones');
INSERT INTO `language_literal` VALUES (73, 3, 'Observations');
INSERT INTO `language_literal` VALUES (74, 1, 'No hi ha generes a mostrar.');
INSERT INTO `language_literal` VALUES (74, 2, 'No hay generos a mostrar.');
INSERT INTO `language_literal` VALUES (74, 3, 'There aren''t generes to show.');
INSERT INTO `language_literal` VALUES (75, 1, 'Icona');
INSERT INTO `language_literal` VALUES (75, 2, 'Icono');
INSERT INTO `language_literal` VALUES (75, 3, 'Icon');
INSERT INTO `language_literal` VALUES (76, 1, 'Nombre mxim de canons');
INSERT INTO `language_literal` VALUES (76, 2, 'Nmero mximo de canciones');
INSERT INTO `language_literal` VALUES (76, 3, 'Max song number');
INSERT INTO `language_literal` VALUES (77, 1, 'Busca a');
INSERT INTO `language_literal` VALUES (77, 2, 'Buscare en:');
INSERT INTO `language_literal` VALUES (77, 3, 'Find in');
INSERT INTO `language_literal` VALUES (78, 1, 'Canons');
INSERT INTO `language_literal` VALUES (78, 2, 'Canciones');
INSERT INTO `language_literal` VALUES (78, 3, 'Songs');
INSERT INTO `language_literal` VALUES (79, 1, 'Artistes');
INSERT INTO `language_literal` VALUES (79, 2, 'Artistas');
INSERT INTO `language_literal` VALUES (79, 3, 'Artists');
INSERT INTO `language_literal` VALUES (80, 1, 'lbums');
INSERT INTO `language_literal` VALUES (80, 2, 'lbumes');
INSERT INTO `language_literal` VALUES (80, 3, 'Albums');
INSERT INTO `language_literal` VALUES (81, 1, 'Gneres');
INSERT INTO `language_literal` VALUES (81, 2, 'Gneros');
INSERT INTO `language_literal` VALUES (81, 3, 'Genres');
INSERT INTO `language_literal` VALUES (82, 1, 'PlayLists');
INSERT INTO `language_literal` VALUES (82, 2, 'PlayLists');
INSERT INTO `language_literal` VALUES (82, 3, 'PlayLists');
INSERT INTO `language_literal` VALUES (83, 1, 'Criteri de selecci');
INSERT INTO `language_literal` VALUES (83, 2, 'Criterios de seleccin');
INSERT INTO `language_literal` VALUES (83, 3, 'Selection criteria');
INSERT INTO `language_literal` VALUES (84, 1, 'Sense criteris (Noms emoci)');
INSERT INTO `language_literal` VALUES (84, 2, 'Sin criterios (Solamente emocin)');
INSERT INTO `language_literal` VALUES (84, 3, 'Without criteria (only emotion)');
INSERT INTO `language_literal` VALUES (85, 1, 'Meves observacions');
INSERT INTO `language_literal` VALUES (85, 2, 'Mis observaciones');
INSERT INTO `language_literal` VALUES (85, 3, 'My observations');
INSERT INTO `language_literal` VALUES (86, 1, 'Meves reproduccions');
INSERT INTO `language_literal` VALUES (86, 2, 'Mis Reproducciones');
INSERT INTO `language_literal` VALUES (86, 3, 'My plays');
INSERT INTO `language_literal` VALUES (87, 1, 'Meu PlayLists');
INSERT INTO `language_literal` VALUES (87, 2, 'Mis PlayLists');
INSERT INTO `language_literal` VALUES (87, 3, 'My PlayLists');
INSERT INTO `language_literal` VALUES (88, 1, 'Meves emocions');
INSERT INTO `language_literal` VALUES (88, 2, 'Mis emociones');
INSERT INTO `language_literal` VALUES (88, 3, 'My emotions');
INSERT INTO `language_literal` VALUES (89, 1, 'Entre');
INSERT INTO `language_literal` VALUES (89, 2, 'Entre');
INSERT INTO `language_literal` VALUES (89, 3, 'Between');
INSERT INTO `language_literal` VALUES (90, 1, 'i');
INSERT INTO `language_literal` VALUES (90, 2, 'y');
INSERT INTO `language_literal` VALUES (90, 3, 'and');
INSERT INTO `language_literal` VALUES (91, 1, 'Escoltada entre');
INSERT INTO `language_literal` VALUES (91, 2, 'Escuchada entre');
INSERT INTO `language_literal` VALUES (91, 3, 'Listened between');
INSERT INTO `language_literal` VALUES (92, 1, 'Mes escoltades');
INSERT INTO `language_literal` VALUES (92, 2, 'Ms escuchadas');
INSERT INTO `language_literal` VALUES (92, 3, 'The most listened ');
INSERT INTO `language_literal` VALUES (93, 1, 'Menys escoltades');
INSERT INTO `language_literal` VALUES (93, 2, 'Menos escuchadas');
INSERT INTO `language_literal` VALUES (93, 3, 'The less listened');
INSERT INTO `language_literal` VALUES (94, 1, 'Les cançons');
INSERT INTO `language_literal` VALUES (94, 2, 'Las canciones');
INSERT INTO `language_literal` VALUES (94, 3, 'The songs');
INSERT INTO `language_literal` VALUES (95, 1, 'La emoci sha creat correctament.');
INSERT INTO `language_literal` VALUES (95, 2, 'La emocin se ha creado correctamente.');
INSERT INTO `language_literal` VALUES (95, 3, 'The emotion has been created correctly.');
INSERT INTO `language_literal` VALUES (96, 1, 'La emoci sha modificat correctament.');
INSERT INTO `language_literal` VALUES (96, 2, 'La emocin se ha modificado correctamente.');
INSERT INTO `language_literal` VALUES (96, 3, 'The emotion has been altered correctly.');
INSERT INTO `language_literal` VALUES (97, 1, 'No hi ha emocions personals definides.');
INSERT INTO `language_literal` VALUES (97, 2, 'No hay emociones personales definidas.');
INSERT INTO `language_literal` VALUES (97, 3, 'There arent personal emotions yet. ');
INSERT INTO `language_literal` VALUES (98, 1, 'La emoci sha esborrat correctament.');
INSERT INTO `language_literal` VALUES (98, 2, 'La emocin se ha borrado correctamente.');
INSERT INTO `language_literal` VALUES (98, 3, 'The emotion has been deleted correctly. ');
INSERT INTO `language_literal` VALUES (99, 1, 'Ttol observaci');
INSERT INTO `language_literal` VALUES (99, 2, 'Ttulo observacin');
INSERT INTO `language_literal` VALUES (99, 3, 'Observation title');
INSERT INTO `language_literal` VALUES (100, 1, 'Selecciona navegaci');
INSERT INTO `language_literal` VALUES (100, 2, 'Selecciona navegacin ');
INSERT INTO `language_literal` VALUES (100, 3, 'Select browse ');
INSERT INTO `language_literal` VALUES (137, 1, 'ltima');
INSERT INTO `language_literal` VALUES (101, 1, 'Es segur que vols eliminar?');
INSERT INTO `language_literal` VALUES (101, 2, 'Esta seguro quieres eliminar?');
INSERT INTO `language_literal` VALUES (101, 3, 'Do you want to delete the element? ');
INSERT INTO `language_literal` VALUES (102, 1, 'Has aconseguit registrar-te amb xit. ');
INSERT INTO `language_literal` VALUES (102, 2, 'Te has registrado correctamente.');
INSERT INTO `language_literal` VALUES (102, 3, 'You have just registered successfully.');
INSERT INTO `language_literal` VALUES (103, 1, 'Modificaci realitzada amb xit.');
INSERT INTO `language_literal` VALUES (103, 2, 'Modificacin realizada correctamente.');
INSERT INTO `language_literal` VALUES (103, 3, 'It has just altered successfully.');
INSERT INTO `language_literal` VALUES (104, 1, 'Idioma');
INSERT INTO `language_literal` VALUES (104, 2, 'Idioma');
INSERT INTO `language_literal` VALUES (104, 3, 'Language');
INSERT INTO `language_literal` VALUES (105, 1, 'Selecciona');
INSERT INTO `language_literal` VALUES (105, 2, 'Selecciona');
INSERT INTO `language_literal` VALUES (105, 3, 'Select');
INSERT INTO `language_literal` VALUES (106, 1, 'canons de:');
INSERT INTO `language_literal` VALUES (106, 2, 'canciones de:');
INSERT INTO `language_literal` VALUES (106, 3, 'songs from:');
INSERT INTO `language_literal` VALUES (107, 1, 'Selecciona emoci');
INSERT INTO `language_literal` VALUES (107, 2, 'Selecciona emocin');
INSERT INTO `language_literal` VALUES (107, 3, 'Select emotion');
INSERT INTO `language_literal` VALUES (108, 1, 'Acci quan es seleccionar');
INSERT INTO `language_literal` VALUES (108, 2, 'Accin cuando se seleccionar ');
INSERT INTO `language_literal` VALUES (108, 3, 'Action when they are selected');
INSERT INTO `language_literal` VALUES (109, 1, 'Seleccionar');
INSERT INTO `language_literal` VALUES (109, 2, 'Seleccionar');
INSERT INTO `language_literal` VALUES (109, 3, 'Select');
INSERT INTO `language_literal` VALUES (110, 1, 'Resultado');
INSERT INTO `language_literal` VALUES (110, 2, 'Resultado');
INSERT INTO `language_literal` VALUES (110, 3, 'Result');
INSERT INTO `language_literal` VALUES (111, 1, 'Seleccionar els elements musicals per tal de escoltar les seves canons');
INSERT INTO `language_literal` VALUES (111, 2, 'Seleccionar los elementos musicales para escuchar sus canciones');
INSERT INTO `language_literal` VALUES (111, 3, 'Select wherever music element from the list to be played their songs');
INSERT INTO `language_literal` VALUES (112, 1, 'No hi ha elements musicals relacionats');
INSERT INTO `language_literal` VALUES (112, 2, 'No hay elementos musicales asociados.');
INSERT INTO `language_literal` VALUES (112, 3, 'There arent music elements to be associates with observations.');
INSERT INTO `language_literal` VALUES (113, 1, 'Element Musical');
INSERT INTO `language_literal` VALUES (113, 2, 'Elemento Musical');
INSERT INTO `language_literal` VALUES (113, 3, 'Music Element');
INSERT INTO `language_literal` VALUES (114, 1, 'totes les');
INSERT INTO `language_literal` VALUES (114, 2, 'todas las ');
INSERT INTO `language_literal` VALUES (114, 3, 'all');
INSERT INTO `language_literal` VALUES (115, 1, 'Es seleccionaran ');
INSERT INTO `language_literal` VALUES (115, 2, 'Se seleccionarn');
INSERT INTO `language_literal` VALUES (115, 3, 'Are going to be selected');
INSERT INTO `language_literal` VALUES (116, 1, 'Seqncia ');
INSERT INTO `language_literal` VALUES (116, 2, 'Secuencia');
INSERT INTO `language_literal` VALUES (116, 3, 'Sequence');
INSERT INTO `language_literal` VALUES (117, 1, 'desar');
INSERT INTO `language_literal` VALUES (117, 2, 'guardar');
INSERT INTO `language_literal` VALUES (117, 3, 'save');
INSERT INTO `language_literal` VALUES (118, 1, 'No hi ha resultats');
INSERT INTO `language_literal` VALUES (118, 2, 'No hay resultados');
INSERT INTO `language_literal` VALUES (118, 3, 'There arent any result search. ');
INSERT INTO `language_literal` VALUES (119, 1, 'Selecciona observaci');
INSERT INTO `language_literal` VALUES (119, 2, 'Selecciona observacin');
INSERT INTO `language_literal` VALUES (119, 3, 'Select an observation');
INSERT INTO `language_literal` VALUES (120, 1, 'La Meva Agenda');
INSERT INTO `language_literal` VALUES (120, 2, 'Mi Agenda');
INSERT INTO `language_literal` VALUES (120, 3, 'My Notebook');
INSERT INTO `language_literal` VALUES (121, 1, 'Descripci ');
INSERT INTO `language_literal` VALUES (121, 2, 'Descripcin ');
INSERT INTO `language_literal` VALUES (121, 3, 'Description');
INSERT INTO `language_literal` VALUES (122, 1, 'Esdeveniments');
INSERT INTO `language_literal` VALUES (122, 2, 'Eventos');
INSERT INTO `language_literal` VALUES (122, 3, 'Events');
INSERT INTO `language_literal` VALUES (123, 1, 'Selecciona un PlayList');
INSERT INTO `language_literal` VALUES (123, 2, 'Selecciona un PlayList');
INSERT INTO `language_literal` VALUES (123, 3, 'Choose a PlayList');
INSERT INTO `language_literal` VALUES (124, 1, 'Les meves canons predilectes');
INSERT INTO `language_literal` VALUES (124, 2, 'Mis Canciones Favoritas');
INSERT INTO `language_literal` VALUES (124, 3, 'My favourite Songs');
INSERT INTO `language_literal` VALUES (125, 1, 'Canons mes escoltades');
INSERT INTO `language_literal` VALUES (125, 2, 'Canciones ms escuchadas');
INSERT INTO `language_literal` VALUES (125, 3, 'The most played songs');
INSERT INTO `language_literal` VALUES (126, 1, 'Les meves canons mes escoltades');
INSERT INTO `language_literal` VALUES (126, 2, 'Mis canciones ms escuchadas');
INSERT INTO `language_literal` VALUES (126, 3, 'My most played songs');
INSERT INTO `language_literal` VALUES (127, 1, 'Canons mes puntuades');
INSERT INTO `language_literal` VALUES (127, 2, 'Canciones ms puntuacin');
INSERT INTO `language_literal` VALUES (127, 3, 'The most punctuated songs');
INSERT INTO `language_literal` VALUES (128, 1, 'Artistes mes puntuats');
INSERT INTO `language_literal` VALUES (128, 2, 'Artistas ms puntuacin');
INSERT INTO `language_literal` VALUES (128, 3, 'The most punctuated artists');
INSERT INTO `language_literal` VALUES (129, 1, 'Nous lbums');
INSERT INTO `language_literal` VALUES (129, 2, 'Nuevos lbumes');
INSERT INTO `language_literal` VALUES (129, 3, 'New albums');
INSERT INTO `language_literal` VALUES (130, 1, 'Meves');
INSERT INTO `language_literal` VALUES (130, 2, 'Mis');
INSERT INTO `language_literal` VALUES (130, 3, 'My');
INSERT INTO `language_literal` VALUES (131, 1, 'Dades');
INSERT INTO `language_literal` VALUES (131, 2, 'Datos');
INSERT INTO `language_literal` VALUES (131, 3, 'Profile');
INSERT INTO `language_literal` VALUES (132, 1, 'Carregar MP3');
INSERT INTO `language_literal` VALUES (132, 2, 'Cargar MP3');
INSERT INTO `language_literal` VALUES (132, 3, 'Load MP3');
INSERT INTO `language_literal` VALUES (133, 1, 'Selecciona criteri de cerca');
INSERT INTO `language_literal` VALUES (133, 2, 'Selecciona criterio de bsqueda');
INSERT INTO `language_literal` VALUES (133, 3, 'Select a field to search');
INSERT INTO `language_literal` VALUES (134, 1, 'Cercar');
INSERT INTO `language_literal` VALUES (134, 2, 'Buscar');
INSERT INTO `language_literal` VALUES (134, 3, 'Search');
INSERT INTO `language_literal` VALUES (135, 1, 'No hi ha emocions');
INSERT INTO `language_literal` VALUES (135, 2, 'No hay emociones');
INSERT INTO `language_literal` VALUES (135, 3, 'There arent emotions');
INSERT INTO `language_literal` VALUES (136, 1, 'Recorda');
INSERT INTO `language_literal` VALUES (136, 2, 'Recuerda');
INSERT INTO `language_literal` VALUES (136, 3, 'Remember');
INSERT INTO `language_literal` VALUES (137, 2, 'ltima');
INSERT INTO `language_literal` VALUES (137, 3, 'Last');

